@@ -8,6 +8,7 @@ import lib.wifi as wifi
 import lib.bt as bt
 import lib.util as util
 import lib.archive as archive
+import lib.img as img
 
 
 main_app = typer.Typer()
@@ -16,6 +17,7 @@ main_app.add_typer(wifi.wifi_app,       name="wifi"   )
 main_app.add_typer(bt.bt_app,           name="bt"     )
 main_app.add_typer(util.util_app,       name="util"   )
 main_app.add_typer(archive.archive_app, name="archive")
+main_app.add_typer(img.img_app,         name="img"    )
 
 
 if __name__ == "__main__":
